==> webform_send_draft_link-1.0.4.tar.gz: webform_send_draft_link/src/Form/WebformSendDraftLinkForm.php <==
<?php

namespace Drupal\webform_send_draft_link\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\webform\WebformInterface;
use Drupal\Component\Utility\Html;
use Drupal\Component\Utility\Xss;

/**
 * Sends a webform draft link via email.
 */
class WebformSendDraftLinkForm extends ConfigFormBase {

  /**
   * The configuration.
   *
   * @var \Drupal\Core\Config\Config
   */
  protected $config;

  /**
   * The url of the link to a draft.
   *
   * @var string
   */
  protected $token_url;  

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    $instance = parent::create($container);
    $instance->config = $instance->config('webform_send_draft_link.settings');
    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'webform_send_draft_link.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'webform_send_draft_link_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, WebformInterface $webform = NULL) {

    if (!$webform->getSetting('token_update')) {
      $this->messenger()->addWarning($this->t('The "Allow users to update a submission using a secure token" option is disabled.'));
      return $form;
    }

    $this->token_url = $webform->getThirdPartySetting('webform_send_draft_link', 'token_url');
    $is_completed = $webform->getThirdPartySetting('webform_send_draft_link', 'is_completed');

    if (empty($this->token_url) && empty($is_completed)) {
      $this->messenger()->addWarning($this->t('The draft has not been saved yet.'));
      return $form;
    }

    if ($is_completed) {
      $this->messenger()->addWarning($this->t('The submission has been already completed.'));
      return $form;
    }

    $from_email = empty($this->config->get('from')) ? $this->currentUser()->getEmail() : $this->config->get('from');

    $form['from'] = [
      '#type' => 'email',
      '#title' => $this->t('From'),
      '#required' => TRUE,
      '#default_value' => $from_email,
    ];

    $form['to'] = [
      '#type' => 'email',
      '#title' => $this->t('To'),
      '#required' => TRUE,
      '#default_value' => $this->config->get('to'),
    ];

    $form['subject'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Subject'),
      '#size' => 60,
      '#maxlength' => 128,
      '#required' => TRUE,
      '#default_value' => $this->config->get('subject'),
    ];

    $form['message'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Message (the link will be attached automatically)'),
      '#rows' => 3,
      '#default_value' => $this->config->get('message'),
    ];

    $form['link'] = [
      '#type' => 'item',
      '#markup' => '<a href="' . $this->token_url . '">' . $this->token_url . '</a>',
    ];

    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Send'),
    ];
    
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

    $from = Html::escape($form_state->getValue('from'));
    $to = Html::escape($form_state->getValue('to'));
    $subject = Html::escape($form_state->getValue('subject'));
    $message = Xss::filterAdmin($form_state->getValue('message'));
    $link = '<a href="' . $this->token_url . '">' . $this->token_url . '</a>';
    $body = $message . '<br>' . $link;

    simple_mail_send($from, $to, $subject, $body);

    $this->config->set('from', $from);
    $this->config->set('to', $to);
    $this->config->set('subject', $subject);
    $this->config->set('message', $message);
    $this->config->save();

    $this->messenger()->addStatus($this->t('The message was sent.'));
  }

}

==> webform_send_draft_link-1.0.5.tar.gz: webform_send_draft_link/src/Form/WebformSendDraftLinkForm.php <==
<?php

namespace Drupal\webform_send_draft_link\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\webform\WebformInterface;
use Drupal\Component\Utility\Html;
use Drupal\Component\Utility\Xss;

/**
 * Sends a webform draft link via email.
 */
class WebformSendDraftLinkForm extends ConfigFormBase {

  /**
   * The configuration.
   *
   * @var \Drupal\Core\Config\Config
   */
  protected $config;

  /**
   * The url of the link to a draft.
   *
   * @var string
   */
  protected $tokenUrl;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    $instance = parent::create($container);
    $instance->config = $instance->config('webform_send_draft_link.settings');
    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'webform_send_draft_link.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'webform_send_draft_link_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, WebformInterface $webform = NULL) {

    if (!$webform->getSetting('token_update')) {
      $this->messenger()->addWarning($this->t('The "Allow users to update a submission using a secure token" option is disabled.'));
      return $form;
    }

    $this->tokenUrl = $webform->getThirdPartySetting('webform_send_draft_link', 'token_url');
    $is_completed = $webform->getThirdPartySetting('webform_send_draft_link', 'is_completed');

    if (empty($this->tokenUrl) && empty($is_completed)) {
      $this->messenger()->addWarning($this->t('The draft has not been saved yet.'));
      return $form;
    }

    if ($is_completed) {
      $this->messenger()->addWarning($this->t('The submission has been already completed.'));
      return $form;
    }

    $form['from'] = [
      '#type' => 'email',
      '#title' => $this->t('From'),
      '#required' => TRUE,
      '#default_value' => $this->currentUser()->getEmail(),
    ];

    $form['to'] = [
      '#type' => 'email',
      '#title' => $this->t('To'),
      '#required' => TRUE,
    ];

    $form['subject'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Subject'),
      '#size' => 60,
      '#maxlength' => 128,
      '#required' => TRUE,
    ];

    $form['message'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Message (the link will be attached automatically)'),
      '#rows' => 3,
    ];

    $form['link'] = [
      '#type' => 'item',
      '#markup' => '<a href="' . $this->tokenUrl . '">' . $this->tokenUrl . '</a>',
    ];

    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Send'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

    $from = Html::escape($form_state->getValue('from'));
    $to = Html::escape($form_state->getValue('to'));
    $subject = Html::escape($form_state->getValue('subject'));
    $message = Xss::filterAdmin($form_state->getValue('message'));
    $link = '<a href="' . $this->tokenUrl . '">' . $this->tokenUrl . '</a>';
    $body = $message . '<br>' . $link;

    simple_mail_send($from, $to, $subject, $body);

    $this->messenger()->addStatus($this->t('The message was sent.'));
  }

}
